const VueLoaderPlugin = require('vue-loader/lib/plugin');

const vueSupport = function (chainedConfig, env) {
  chainedConfig.module
    .rule('vue')
    .test(/\.vue$/)
    .use('cache-loader')
    .loader(require.resolve('cache-loader'))
    .end()
    .use('vue-loader')
    .loader(require.resolve('vue-loader'))
    .end();

  if (env === 'DEBUG') {
    chainedConfig.module
      .rule('css-preprocessor')
      .test(/\.(scss|less)$/)
      .use('vue-style-loader')
      .loader(require.resolve('vue-style-loader'))
      .before('css-loader');

    chainedConfig.module
      .rule('style')
      .test(/\.css$/)
      .use('vue-style-loader')
      .loader(require.resolve('vue-style-loader'))
      .before('css-loader');
  }

  chainedConfig.plugin('vue-loader-plugin')
    .use(VueLoaderPlugin);
};

module.exports.options = function (joi) {

};

module.exports.clientConf = function (chainedConfig, env, config) {
  vueSupport(chainedConfig);
};

module.exports.serverConf = function (chainedConfig, env, config) {
  vueSupport(chainedConfig);
};

module.exports.dllConf = function (chainedConfig, env, config) {
  vueSupport(chainedConfig);
};

module.exports.generate = (options) => {
  const userPkg = require(require('path').resolve(process.cwd(), './package.json'));
  return {
    dependencies: {
      ...(userPkg.dependencies.vue ? {} : { vue: '2.6.14' }),
      ...(userPkg.dependencies['vue-template-compiler'] ? {} : { 'vue-template-compiler': '2.6.14' }), // vue-template-compiler 保证版本一致性, 需添加
    },
  };
};

